@@ -442,7 +442,7 @@ impl<P: Sync + Send + Serialize + DeserializeOwned> Checkout<P> {
         ctx.update_checkout(self).await
     }
 
-    pub async fn revert<C: Context + Send>(&mut self, ctx: &mut C) -> Result<(), Error> {
+    pub async fn release<C: Context + Send>(&mut self, ctx: &mut C) -> Result<(), Error> {
         match self.state {
             State::Shopping => Ok(()),
             State::ItemsConfirmed(_) | State::PaymentInProgress(_) => {
